# ConcealPass

**ConcealPass** is a Python package for collecting user password input and allowing the input
to be masked. The password is then returned (in plain text) to be stored or used for other purposes.
